Learn R Programming

svTools (version 0.9-0)

generateRoxygenTemplate: Roxygen template generator

Description

Generate a default Roxygen template for this file.

Usage

generateRoxygenTemplate(file, row, column, author = getOption("svTools.roxygen.author"),
    type = c("verbatim", "supperabbrev"))

Arguments

file
code file in which to add a roxygen roclet.
row
line in the file.
column
column in the file.
author
author. The default value uses the option "svTools.roxygen.author".
type
type of output. "verbatim" is plain text. "superabbrev" is specific to jedit

Value

  • A character string that contains the roxygen comments to add in the file.

concept

inline documentation with oxygen

References

Roxygen. http://roxygen.org/

See Also

completeRoxygen