Learn R Programming

svTools (version 0.0-12)

generateRoxygenTemplate: Roxygen template generator

Description

Roxygen template generator

Usage

generateRoxygenTemplate(file, row, col, 
	author = getOption("svTools.roxygen.author"), 
	type = c("verbatim", "supperabbrev"))

Arguments

file
code file in which to add a roxygen roclet
row
line in the file
col
column in the file
author
author. The default value uses the option "svTools.roxygen.author"
type
type of output. verbatim is plain text. superabbrev is specific to jedit

Value

  • A character string that contains the roxygen comments to add in the file

References

Roxygen. http://roxygen.org/